@@ -27,17 +27,18 @@ Observation, ObservationMetadata, Tile, Postprocessing = None, None, None, None
 KinematicModel = None
 
 
-def connect(path="/mnt/shared/wallaby/apps/WALLABY_database"):
-    """Establish connection to database through Django models
+def connect(db="/mnt/shared/wallaby/apps/WALLABY_database", env="/mnt/shared/wallaby/apps/WALLABY_data_access/wallaby_data_access/.env"):
+    """Establish connection to database through Django models.
+    Need to specify path to database directory and .env file for Django settings environment variables.
 
     """
     global Run, Instance, Detection, Product, Source
     global SourceDetection, Comment, Tag, TagSourceDetection
     global Observation, ObservationMetadata, Tile, Postprocessing
     global KinematicModel
-    load_dotenv(os.path.join(os.path.dirname(os.path.abspath(__file__)), '.env'))
-    sys.path.append(path)
-    sys.path.append(path + "/orm")
+    load_dotenv(env)
+    sys.path.append(db)
+    sys.path.append(db + "/orm")
     django.setup()
     from source_finding.models import Run, Instance, Detection, Product, Source
     from source_finding.models import SourceDetection, Comment, Tag, TagSourceDetection
